<?php

namespace Drupal\ad_inserter\Plugin\Block;

use Drupal\ad_inserter\AdInserterStorage;
use Drupal\ad_inserter\Entity\AdInserter;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Cache\Cache;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

abstract class AdInserterBaseBlock extends BlockBase implements ContainerFactoryPluginInterface, AdInserterBaseBlockInterface {

  protected AdInserter|null $adInserter = NULL;

  /**
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * @var AdInserterStorage
   */
  protected AdInserterStorage $adInserterStorage;

  protected ModuleHandlerInterface $moduleHandler;

  /**
   * @param array $configuration
   * @param $plugin_id
   * @param $plugin_definition
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entityTypeManager, ModuleHandlerInterface $moduleHandler) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->entityTypeManager = $entityTypeManager;
    $this->adInserterStorage = $entityTypeManager->getStorage('ad_inserter');
    $this->moduleHandler = $moduleHandler;
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('module_handler')
    );
  }

  public function build() {
    $this->getAdInserter();
    // Ensure is active and exist.
    if (!$this->adInserter || !$this->adInserter->isActive()) {
      return NULL;
    }
    $options = [
      'status' => TRUE,
    ];
    // Alter option to show.
    $this->moduleHandler->invokeAll('ad_inserter_alter_status', [$this->adInserter, &$options]);

    if ($options['status'] === FALSE) {
      return NULL;
    }
    $build['#attributes']['class'][] = 'ad-inserter-block';
    // We always hidden ad inserter before js not showing them.
    if ($this->adInserter->getScreen() != 'all') {
      $build['#attributes']['class'][] = 'hidden';
    }
    $build['#attributes']['data-ad-inserter-id'] = $this->adInserter->id();
    $build['#attributes']['data-ad-inserter-screen'] = $this->adInserter->getScreen();
    $machineName = $this->adInserter->getMachineName();
    if ($machineName) {
      $build['#attributes']['data-ad-inserter-machine-name'] = $machineName;
    }
    $build['#attached']['library'][] = 'ad_inserter/loader';
    $build['ad_inserter'] = $this->entityTypeManager->getViewBuilder('ad_inserter')->view($this->adInserter);
    return $build;
  }


  /**
   * {@inheritdoc}
   */
  public function getCacheTags() {
    $this->getAdInserter();
    if ($this->adInserter) {
      return Cache::mergeTags(parent::getCacheTags(), $this->adInserter->getCacheTags());
    }
    return parent::getCacheTags();
  }

}
